@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.129-9-g0960324
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.130-11-gf3164b9
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.130';
+our $VERSION = '0.131';
 
 use Moose;
 with
@@ -183,13 +183,13 @@ has _removed_plugins => (
 
 # this attribute and its supporting code is a candidate to be extracted out into its own role,
 # for re-use in other bundles
-has _develop_requires => (
+has _develop_suggests => (
     isa => class_type('CPAN::Meta::Requirements'),
     lazy => 1,
     default => sub { CPAN::Meta::Requirements->new },
     handles => {
-        _add_minimum_develop_requires => 'add_minimum',
-        _develop_requires_as_string_hash => 'as_string_hash',
+        _add_minimum_develop_suggests => 'add_minimum',
+        _develop_suggests_as_string_hash => 'as_string_hash',
     },
 );
 
@@ -299,7 +299,7 @@ sub configure
         [ 'PodCoverageTests'    => { ':version' => '5.040' } ],
         [ 'Test::PodSpelling'   => { ':version' => '2.006003', stopwords => ['irc'], directories => [qw(examples lib script t xt)] } ],
         #[Test::Pod::LinkCheck]     many outstanding bugs
-        ($ENV{TRAVIS} ? () : [ 'Test::Pod::No404s'   => { ':version' => '1.003' } ] ),
+        ($ENV{CONTINUOUS_INTEGRATION} ? () : [ 'Test::Pod::No404s' => { ':version' => '1.003' } ] ),
         [ 'Test::Kwalitee'      => { ':version' => '2.10', filename => 'xt/author/kwalitee.t' } ],
         [ 'MojibakeTests'       => { ':version' => '0.8' } ],
         [ 'Test::ReportPrereqs' => { ':version' => '0.022', verify_prereqs => 1,
@@ -340,14 +340,14 @@ sub configure
         # Register Prereqs
         # (MakeMaker or other installer)
         [ 'AutoPrereqs'         => { ':version' => '5.038' } ],
-        [ 'Prereqs::AuthorDeps' => { ':version' => '0.006' } ],
+        [ 'Prereqs::AuthorDeps' => { ':version' => '0.006', relation => 'suggests' } ],
         [ 'MinimumPerl'         => { ':version' => '1.006', configure_finder => ':NoFiles' } ],
         [ 'Prereqs' => pluginbundle_version => {
                 '-phase' => 'develop', '-relationship' => 'recommends',
                 $self->meta->name => $self->VERSION,
             } ],
         ($self->surgical_podweaver ? [ 'Prereqs' => pod_weaving => {
-                '-phase' => 'develop', '-relationship' => 'requires',
+                '-phase' => 'develop', '-relationship' => 'suggests',
                 'Dist::Zilla::Plugin::SurgicalPodWeaver' => 0
             } ] : ()),
 
@@ -466,8 +466,8 @@ sub configure
     # ensure that additional optional plugins are declared in prereqs
     $self->add_plugins(
         [ 'Prereqs' => 'prereqs for @Author::ETHER' =>
-        { '-phase' => 'develop', '-relationship' => 'requires',
-          %{ $self->_develop_requires_as_string_hash } } ]
+        { '-phase' => 'develop', '-relationship' => 'suggests',
+          %{ $self->_develop_suggests_as_string_hash } } ]
     );
 
     # listed last, to be sure we run at the very end of each phase
@@ -507,7 +507,7 @@ around add_plugins => sub
             my %configs = %{ $extra_args{$module} };    # copy, not reference!
 
             # don't keep :version unless it matches the package exactly, but still respect the prereq
-            $self->_add_minimum_develop_requires($module => delete $configs{':version'})
+            $self->_add_minimum_develop_suggests($module => delete $configs{':version'})
                 if exists $configs{':version'} and $module ne $plugin;
 
             # we don't need to worry about overwriting the payload with defaults, as
@@ -516,7 +516,7 @@ around add_plugins => sub
         }
 
         # record develop prereq
-        $self->_add_minimum_develop_requires($plugin => $payload->{':version'} // 0);
+        $self->_add_minimum_develop_suggests($plugin => $payload->{':version'} // 0);
     }
 
     return $self->$orig(@plugins);
@@ -537,7 +537,7 @@ around add_bundle => sub
     # default configs can be passed in directly - no need to consult %extra_args
 
     # record develop prereq of bundle only, not its components (it should do that itself)
-    $self->_add_minimum_develop_requires($package => $payload->{':version'} // 0);
+    $self->_add_minimum_develop_suggests($package => $payload->{':version'} // 0);
 
     # allow config slices to propagate down from the user
     $payload = {
@@ -581,7 +581,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.130
+version 0.131
 
 =head1 SYNOPSIS
 
@@ -775,18 +775,14 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [AutoPrereqs]
     :version = 5.038
     [Prereqs::AuthorDeps]
+    relation = suggests
     [MinimumPerl]
     :version = 1.006
     configure_finder = :NoFiles
 
-    [Prereqs / installer_requirements]
-    -phase = develop
-    -relationship = requires
-    Dist::Zilla::PluginBundle::Author::ETHER = <version specified in dist.ini>
-
     [Prereqs / prereqs for @Author::ETHER]
     -phase = develop
-    -relationship = requires
+    -relationship = suggests
     ...all the plugins this bundle uses...
 
     [Prereqs / pluginbundle_version]
@@ -1213,13 +1209,13 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Dave Rolsky Graham Knop Randy Stauner Roy Ivy III Сергей Романов
+=for stopwords Edward Betts Graham Knop Dave Rolsky Randy Stauner Roy Ivy III Сергей Романов
 
 =over 4
 
 =item *
 
-Dave Rolsky <autarch@urth.org>
+Edward Betts <edward@4angle.com>
 
 =item *
 
@@ -1227,6 +1223,10 @@ Graham Knop <haarg@haarg.org>
 
 =item *
 
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
 Randy Stauner <rwstauner@cpan.org>
 
 =item *
