@@ -66,37 +66,35 @@ sub assert_no_git
 # checks that all plugins in use are in the plugin bundle dist's runtime
 # requires list
 # - some plugins can be marked 'additional' - must be in recommended prereqs
-#   AND the built dist's develop requires list
-# - some plugins can be explicitly exempted (added manually to faciliate
+#   AND the built dist's develop suggests list
+# - some plugins can be explicitly exempted (added manually to facilitate
 #   testing)
 # TODO: move into its own distribution
 sub all_plugins_in_prereqs
 { SKIP: {
-    skip('this test requires a built dist', 1) if not -f 'META.json';
-
     my ($tzil, %options) = @_;
 
     my $bundle_name = $options{bundle_name} // '@Author::ETHER';    # TODO: default to dist we are in
     my %additional = map { $_ => undef } @{ $options{additional} // [] };
     my %exempt = map { $_ => undef } @{ $options{exempt} // [] };
 
-    my $pluginbundle_meta = decode_json(path('META.json')->slurp_raw);
+    my $pluginbundle_meta = -f 'META.json' ? decode_json(path('META.json')->slurp_raw) : undef;
     my $dist_meta = $tzil->distmeta;
 
-    # these are develop-requires prereqs
+    # these are develop-suggests prereqs
     my $plugin_name = "$bundle_name/prereqs for $bundle_name";
     my $bundle_plugin_prereqs = $tzil->plugin_named($plugin_name);
     cmp_deeply(
         $bundle_plugin_prereqs,
         methods(
             prereq_phase => 'develop',
-            prereq_type => 'requires',
+            prereq_type => 'suggests',
         ),
-        "found '$plugin_name' develop-requires prereqs",
+        "found '$plugin_name' develop-suggests prereqs",
     );
     $bundle_plugin_prereqs = $bundle_plugin_prereqs->_prereq;
 
-    subtest 'all plugins in use are specified as *required* runtime prerequisites by the plugin bundle, or develop prerequisites by the distribution' => sub {
+    subtest 'all plugins in use are specified as *required* runtime prerequisites by the plugin bundle, or develop-suggests prerequisites by the distribution' => sub {
         foreach my $plugin (uniq map { find_meta($_)->name }
             grep { $_->plugin_name =~ /^$bundle_name\/[^@]/ } @{$tzil->plugins})
         {
@@ -104,7 +102,12 @@ sub all_plugins_in_prereqs
                 if exists $exempt{$plugin};
 
             # cannot be a (non-develop) prereq if the module lives in this distribution
-            next if exists $pluginbundle_meta->{provides}{$plugin};
+            next if (
+                $pluginbundle_meta ? exists $pluginbundle_meta->{provides}{$plugin}
+               : do {
+                   (my $file = $plugin) =~ s{::}{/}g; $file .= '.pm';
+                   path('lib', $file)->exists;
+               });
 
             # plugins with a specific :version requirement are added to
             # prereqs via an extra injected [Prereqs] plugin
@@ -115,7 +118,7 @@ sub all_plugins_in_prereqs
                 # plugin was added in via an extra option, therefore the
                 # plugin should have been added to develop prereqs, and not be a runtime prereq
                 ok(
-                    exists $dist_meta->{prereqs}{develop}{requires}{$plugin},
+                    exists $dist_meta->{prereqs}{develop}{suggests}{$plugin},
                     $plugin . ' is a develop prereq of the distribution',
                 );
 
@@ -123,7 +126,7 @@ sub all_plugins_in_prereqs
                     $pluginbundle_meta->{prereqs}{runtime}{recommends},
                     superhashof({ $plugin => $required_version }),
                     $plugin . ' is a runtime recommendation of the plugin bundle',
-                );
+                ) if $pluginbundle_meta;
             }
             else
             {
@@ -132,10 +135,12 @@ sub all_plugins_in_prereqs
                     $pluginbundle_meta->{prereqs}{runtime}{requires},
                     superhashof({ $plugin => $required_version }),
                     $plugin . ' is a runtime prereq of the plugin bundle',
-                );
+                ) if $pluginbundle_meta;
             }
         }
 
+        pass 'this is a token test to keep things humming' if not $pluginbundle_meta;
+
         if (not Test::Builder->new->is_passing)
         {
             diag 'got dist metadata: ', explain $dist_meta;
